#!/bin/sh
#*******************************************************************************
# IBM_PROLOG_BEGIN_TAG
# This is an automatically generated prolog.
#
# Licensed Materials - Property of IBM
#
# COPYRIGHT International Business Machines Corp.  2015, 2016
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
#
# IBM_PROLOG_END_TAG
#*******************************************************************************
#
# This script contains the pre-start content for pvm-core.conf (/etc/init/)
# upstart.  We separate this out so that it can be called separate from
# upstart for certain installer scenarios.
#
# If this script exits with a failure, then the pvm-core service will not
# start up.  After this has been run, you will still need to start the
# runtime yourself with:
#
# /usr/sbin/pvm_apd
#
# The above will NOT background the process, and should be run as root.
#
########################################################
    # Load ibmvmc module if needed

    MODULE_NAME="ibmvmc"
    lsmod | grep -q $MODULE_NAME
    if [ $? -ne 0 ]; then
        modprobe $MODULE_NAME
        if [ $? -ne 0 ]; then
            # Without ibmvmc we cannot do much
            echo "Error loading ${MODULE_NAME} module\n"
            exit 1
        fi
    fi
    # Update IBM.LparCmd acl's to allow any user in pvm-admin read/write access
    if [ -f /usr/bin/members ] || [ -f /bin/members ]; then
        users=`members pvm_admin`
    elif [ -f /usr/sbin/groupmems ] || [ -f /sbin/groupmems]; then
        users=`groupmems -g pvm_admin -l`
    else
        echo "ERROR: Unable to determine users in pvm_admin group - this likely will cause problems..."
    fi
    user_num=1
    for user in $users
    do
        [ -z $user ] && break;
        wlpacl="IBM.LparCmd$(printf '\n\t')${user}@LOCALHOST   *   rw  // Added by the pvm-core-pre-start script"
        # Increment our user_num
        user_num=$(expr ${user_num} + 1);
        # Add the acl
        echo "Adding the following acl: ${wlpacl}"
        echo "${wlpacl}" | /opt/rsct/install/bin/chrmcacl -a
    done

    # User wlp needs to be able to notify IBM.MngNode of partition change events
    wlpacl="IBM.MngNode$(printf '\n\t')wlp@LOCALHOST   *   rw  // Added by the pvm-core-pre-start script"
    echo "Adding the following acl: ${wlpacl}"
    echo "${wlpacl}" | /opt/rsct/install/bin/chrmcacl -a

    if [ $user_num -gt 1 ]; then
        /usr/bin/refresh -s ctrmc || echo "ctrmc not up yet - so no need to refresh..."
    fi


    # Enable our backup & RAID crontab entries.  If the entry already exists - even if it's
    # had the timing modified, don't touch it.
    vios_hourly="15 1-23 * * * /usr/sbin/pvm-backup --type vios --frequency hourly"
    system_hourly="15 1-23 * * * /usr/sbin/pvm-backup --type system --frequency hourly"
    vios_daily="15 0    * * * /usr/sbin/pvm-backup --type vios --frequency daily"
    system_daily="15 0    * * * /usr/sbin/pvm-backup --type system --frequency daily"
    raid_rebuild="*/15 *   * * * /usr/sbin/pvm-rebuild-raid --quiet"
    vios_healthcheck="*/5 *   * * * /usr/sbin/pvm-vios-health-check"

    tmp_cron_file="/tmp/tmp_cron_root"

    /usr/bin/crontab -l > $tmp_cron_file
    grep -q -F "/usr/sbin/pvm-backup --type vios --frequency hourly" $tmp_cron_file
    if [ $? -ne 0 ]; then
        echo "# VIOS hourly backups - at 15 past every hour except for midnight" >> $tmp_cron_file
        echo "$vios_hourly" >> $tmp_cron_file
    fi
    grep -q -F "/usr/sbin/pvm-backup --type system --frequency hourly" $tmp_cron_file
    if [ $? -ne 0 ]; then
        echo "# Hypervisor hourly backups - at 15 past every hour except for midnight" >> $tmp_cron_file
        echo "$system_hourly" >> $tmp_cron_file
    fi
    grep -q -F "/usr/sbin/pvm-backup --type vios --frequency daily" $tmp_cron_file
    if [ $? -ne 0 ]; then
        echo "# VIOS daily backups - at 15 past midnight" >> $tmp_cron_file
        echo "$vios_daily" >> $tmp_cron_file
    fi
    grep -q -F "/usr/sbin/pvm-backup --type system --frequency daily" $tmp_cron_file
    if [ $? -ne 0 ]; then
        echo "# Hypervisor daily backups - at 15 past midnight" >> $tmp_cron_file
        echo "$system_daily" >> $tmp_cron_file
    fi
    grep -q -F "pvm-rebuild-raid" $tmp_cron_file
    if [ $? -ne 0 ]; then
        echo "# RAID 1 rebuild (if needed) - every 15 minutes" >> $tmp_cron_file
        echo "$raid_rebuild" >> $tmp_cron_file
    fi
    grep -q -F "pvm-vios-health-check" $tmp_cron_file
    if [ $? -ne 0 ]; then
        echo "# Check VIOS health state and recover (if needed) - every 5 minutes" >> $tmp_cron_file
        echo "$vios_healthcheck" >> $tmp_cron_file
    fi

    # Write out the crontab
    /usr/bin/crontab $tmp_cron_file
    rm -rf $tmp_cron_file

    # Clean the access process if needed
    test -x /usr/sbin/pvm_apd || { echo "pvm_apd not found - exiting"; exit 1; }
    /usr/sbin/pvm_apd --clean
